/*------------------------------------------------------------------------------
-- This file is a part of the QLop Software
-- Copyright (C) 2015, Plasma Physics Laboratory - CNRS
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-------------------------------------------------------------------------------*/
/*-- Author : Alexis Jeandet
-- Mail : alexis.jeandet@member.fsf.org
----------------------------------------------------------------------------*/

#ifndef FILEBROWSER_H
#define FILEBROWSER_H

#include <QDockWidget>
#include <QFileSystemModel>
#include <QAbstractItemView>
#include <filesystemmodel.h>
#include <QKeyEvent>
#include <QCompleter>

namespace Ui {
class FileBrowser;
}

class FileBrowser : public QDockWidget
{
    Q_OBJECT

public:
    explicit FileBrowser(QWidget *parent = 0);
    ~FileBrowser();
    void setNameFilters(const QStringList & filters, bool disables=false);
signals:
    void fileClicked(const QString& file);
    void fileDoubleClicked(const QString& file);
private slots:
    void changeToTreeView();
    void changeToListView();
    void clicked(QModelIndex index);
    void doubleClicked(QModelIndex index);
    void parentDir();
    void cd(const QString& newPath);
protected:
    void changeEvent(QEvent *e);
    void keyPressEvent(QKeyEvent *e);
private:
    void pathLineEditEnterEditMode(bool enter=true);
    Ui::FileBrowser *ui;
    FileSystemModel* model;
    QAbstractItemView* view;
    QCompleter* pathCompleter;
};

#endif // FILEBROWSER_H
